Oktavia for Python
=======================

This is a search engine based on FM-index.
This is a Python port of original JSX version.

Development
----------------

Testing
~~~~~~~

.. code-block:: bash

   $ nosetests tests

Link
---------

* JSX version: https://github.com/shibukawa/oktavia
* Python version: https://github.com/shibukawa/oktavia.py
* Web Site: http://oktavia.info
